@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2006-2008 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2006-2011 Juha Kautto  (juha at xfce.org)
  * Copyright (c) 2005-2006 Mickael Graf (korbinus at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,11 +32,17 @@
 
 #define ORAGE_DIR "orage" G_DIR_SEPARATOR_S
 #define ORAGE_PAR_FILE  "oragerc"
+#define ORAGE_PAR_DIR_FILE ORAGE_DIR ORAGE_PAR_FILE
 #define ORAGE_APP_FILE  "orage.ics"
+#define ORAGE_APP_DIR_FILE ORAGE_DIR ORAGE_APP_FILE
 #define ORAGE_ARC_FILE  "orage_archive.ics"
+#define ORAGE_ARC_DIR_FILE ORAGE_DIR ORAGE_ARC_FILE
 #define ORAGE_CATEGORIES_FILE "orage_categories.txt"
+#define ORAGE_CATEGORIES_DIR_FILE ORAGE_DIR ORAGE_CATEGORIES_FILE
 #define ORAGE_PERSISTENT_ALARMS_FILE "orage_persistent_alarms.txt"
+#define ORAGE_PERSISTENT_ALARMS_DIR_FILE ORAGE_DIR ORAGE_PERSISTENT_ALARMS_FILE
 #define ORAGE_DEFAULT_ALARM_FILE "orage_default_alarm.txt"
+#define ORAGE_DEFAULT_ALARM_DIR_FILE ORAGE_DIR ORAGE_DEFAULT_ALARM_FILE
 
 #define ORAGE_STR_EXISTS(str) ((str != NULL) && (str[0] != 0))
 
@@ -48,6 +54,9 @@
 typedef struct _OrageRc
 {
     void *rc;
+    gboolean read_only;
+    const char *file_name;
+    const char *cur_group;
 } OrageRc;
 
 void program_log (const char *format, ...);
@@ -76,6 +85,7 @@ GtkWidget *orage_image_menu_item_new_from_stock(const gchar *stock_id
 GtkWidget *orage_separator_menu_item_new(GtkWidget *menu);
 GtkWidget *orage_menu_item_new_with_mnemonic(const gchar *label
         , GtkWidget *menu);
+char *orage_replace_text(char *text, char *old, char *new);
 char *orage_process_text_commands(char *text);
 GtkWidget *orage_period_hbox_new(gboolean head_space, gboolean tail_space
         , GtkWidget *spin_dd, GtkWidget *dd_label
@@ -104,8 +114,8 @@ gint orage_days_between(struct tm *t1, struct tm *t2);
 void orage_select_date(GtkCalendar *cal, guint year, guint month, guint day);
 void orage_select_today(GtkCalendar *cal);
 
-gchar *orage_data_file_location(char *name);
-gchar *orage_config_file_location(char *name);
+gchar *orage_data_file_location(char *dir_name);
+gchar *orage_config_file_location(char *dir_name);
 OrageRc *orage_rc_file_open(char *fpath, gboolean read_only);
 void orage_rc_file_close(OrageRc *orc);
 gchar **orage_rc_get_groups(OrageRc *orc);
@@ -130,4 +140,7 @@ gint orage_error_dialog(GtkWindow *parent
 GtkWidget *orage_create_framebox_with_content(const gchar *title
         , GtkWidget *content);
 
+/* NOTE: the following is in main.c */
+void orage_toggle_visible(void);
+
 #endif /* !__ORAGE_FUNCTIONS_H__ */
