@@ -236,6 +236,7 @@ static void print_help(void)
     g_print(_("--toggle (-t) \t\tmake orage visible/unvisible\n"));
     g_print(_("--add-foreign (-a) file [RW] \tadd a foreign file\n"));
     g_print(_("--remove-foreign (-r) file \tremove a foreign file\n"));
+    g_print(_("--export (-e) file [appointment...] \texport appointments from Orage to file\n"));
     g_print("\n");
     g_print(_("files=ical files to load into orage\n"));
 #ifndef HAVE_DBUS
@@ -266,10 +267,39 @@ static void import_file(gboolean running, char *file_name, gboolean initialized)
     }
 }
 
+static void export_file(gboolean running, char *file_name, gboolean initialized
+        , gchar *uid_list)
+{
+    gint type = 0;
+    
+    if (uid_list)
+        type = 1;
+    else
+        type = 0;
+    g_print("export_file: running=%d initialized= %d type=%d, file=%s, uids=%s\n", running, initialized, type, file_name, uid_list);
+    if (running && !initialized) {
+        /* let's use dbus since server is running there already */
+#ifdef HAVE_DBUS
+        if (orage_dbus_export_file(file_name, type, uid_list))
+            orage_message(40, "export done to file=%s", file_name);
+        else
+            g_warning("export failed file=%s\n", file_name);
+#else
+        g_warning("Can not do export without dbus. failed file=%s\n", file_name);
+#endif
+    }
+    else if (!running && initialized) { /* do it self directly */
+        if (xfical_export_file(file_name, type, uid_list))
+            orage_message(40, "export done to file=%s", file_name);
+        else
+            g_warning("export failed file=%s\n", file_name);
+    }
+}
+
 static void add_foreign(gboolean running, char *file_name, gboolean initialized
         , gboolean read_only)
 {
-    if (running && !initialized) 
+    if (running && !initialized) {
         /* let's use dbus since server is running there already */
 #ifdef HAVE_DBUS
         if (orage_dbus_foreign_add(file_name, read_only))
@@ -279,6 +309,7 @@ static void add_foreign(gboolean running, char *file_name, gboolean initialized
 #else
         g_warning("Can not do add foreign file without dbus. failed file=%s\n", file_name);
 #endif
+    }
     else if (!running && initialized) { /* do it self directly */
         if (orage_foreign_file_add(file_name, read_only))
             orage_message(40, "add done foreign file=%s", file_name);
@@ -289,7 +320,7 @@ static void add_foreign(gboolean running, char *file_name, gboolean initialized
 
 static void remove_foreign(gboolean running, char *file_name, gboolean initialized)
 {
-    if (running && !initialized) 
+    if (running && !initialized) {
         /* let's use dbus since server is running there already */
 #ifdef HAVE_DBUS
         if (orage_dbus_foreign_remove(file_name))
@@ -299,6 +330,7 @@ static void remove_foreign(gboolean running, char *file_name, gboolean initializ
 #else
         g_warning("Can not do remove foreign file without dbus. failed file=%s\n", file_name);
 #endif
+    }
     else if (!running && initialized) { /* do it self directly */
         if (orage_foreign_file_remove(file_name))
             orage_message(40, "remove done foreign file=%s", file_name);
@@ -313,6 +345,8 @@ static gboolean process_args(int argc, char *argv[], gboolean running
     int argi;
     gboolean end = FALSE;
     gboolean foreign_file_read_only = TRUE;
+    gchar *export_uid_list = NULL;
+    gchar *file_name = NULL;
 
     if (running && argc == 1) { /* no parameters */
         raise_orage();
@@ -383,6 +417,21 @@ static gboolean process_args(int argc, char *argv[], gboolean running
                 remove_foreign(running, argv[++argi], initialized);
             }
         }
+        else if (!strcmp(argv[argi], "--export") ||
+                 !strcmp(argv[argi], "-e")) {
+            if (argi+1 >= argc) {
+                g_print("\nFile not specified\n\n");
+                print_help();
+                end = TRUE;
+            } 
+            else {
+                file_name = argv[++argi];
+                if (argi+1 < argc) {
+                    export_uid_list = argv[++argi];
+                }
+                export_file(running, file_name, initialized, export_uid_list);
+            }
+        }
         else if (argv[argi][0] == '-') {
             g_print(_("\nUnknown option %s\n\n"), argv[argi]);
             print_help();
