@@ -390,6 +390,7 @@ static void add_info_row(xfical_appt *appt, GtkBox *parentBox, gboolean todo)
     /***** add data into the vbox *****/
     ev = gtk_event_box_new();
     tmp_title = orage_process_text_commands(appt->title);
+    s_time = g_strdup(orage_icaltime_to_i18_time(appt->starttimecur));
     if (appt->allDay || todo) {
         tmp = g_strdup_printf("  %s", tmp_title);
     }
@@ -398,9 +399,13 @@ static void add_info_row(xfical_appt *appt, GtkBox *parentBox, gboolean todo)
                     appt->starttimecur));
         today = orage_tm_time_to_icaltime(orage_localtime());
         if (!strncmp(today, appt->starttimecur, 8)) /* today */
-            tmp = g_strdup_printf(" %s* %s", s_timeonly, appt->title);
-        else
-            tmp = g_strdup_printf(" %s  %s", s_timeonly, appt->title);
+            tmp = g_strdup_printf(" %s* %s", s_timeonly, tmp_title);
+        else {
+            if (g_par.show_event_days > 1)
+                tmp = g_strdup_printf(" %s  %s", s_time, tmp_title);
+            else
+                tmp = g_strdup_printf(" %s  %s", s_timeonly, tmp_title);
+        }
         g_free(s_timeonly);
     }
     label = gtk_label_new(tmp);
@@ -436,7 +441,6 @@ static void add_info_row(xfical_appt *appt, GtkBox *parentBox, gboolean todo)
 
     /***** set hint *****/
     tmp_note = orage_process_text_commands(appt->note);
-    s_time = g_strdup(orage_icaltime_to_i18_time(appt->starttimecur));
     if (todo) {
         na = _("Never");
         e_time = g_strdup(appt->use_due_time
@@ -506,11 +510,20 @@ static void info_process(gpointer a, gpointer pbox)
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
+    /*
+    orage_message(100, "%s %s", P_N, appt->uid);
+    if (appt->freq == XFICAL_FREQ_HOURLY) {
+        orage_message(100, "%s %s", P_N, "HOURLY");
+        if (appt->priority >= g_par.priority_list_limit)
+            orage_message(100, "%s %s", P_N, " low priority HOURLY");
+    }
+    */
     if (pbox == cal->mTodo_rows_vbox)
         todo = TRUE;
     else
         todo = FALSE;
-    add_info_row(appt, box, todo);
+    if (appt->priority < g_par.priority_list_limit)
+        add_info_row(appt, box, todo);
     xfical_appt_free(appt);
 }
 
@@ -558,25 +571,28 @@ static void create_mainbox_event_info_box(void)
     cal->mEvent_vbox = gtk_vbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(cal->mVbox), cal->mEvent_vbox, TRUE, TRUE, 0);
     cal->mEvent_label = gtk_label_new(NULL);
-    if (g_par.show_event_days == 1) {
-        tmp2 = g_strdup(orage_tm_date_to_i18_date(&tm_date_start));
-        tmp = g_strdup_printf(_("<b>Events for %s:</b>"), tmp2);
-        g_free(tmp2);
-    }
-    else {
-        int i;
+    if (g_par.show_event_days) {
+    /* bug 7836: we call this routine also with 0 = no event data at all */
+        if (g_par.show_event_days == 1) {
+            tmp2 = g_strdup(orage_tm_date_to_i18_date(&tm_date_start));
+            tmp = g_strdup_printf(_("<b>Events for %s:</b>"), tmp2);
+            g_free(tmp2);
+        }
+        else {
+            int i;
 
-        tm_date_end = tm_date_start;
-        for (i = g_par.show_event_days-1; i; i--)
-            orage_move_day(&tm_date_end, 1);
-        tmp2 = g_strdup(orage_tm_date_to_i18_date(&tm_date_start));
-        tmp3 = g_strdup(orage_tm_date_to_i18_date(&tm_date_end));
-        tmp = g_strdup_printf(_("<b>Events for %s - %s:</b>"), tmp2, tmp3);
-        g_free(tmp2);
-        g_free(tmp3);
+            tm_date_end = tm_date_start;
+            for (i = g_par.show_event_days-1; i; i--)
+                orage_move_day(&tm_date_end, 1);
+            tmp2 = g_strdup(orage_tm_date_to_i18_date(&tm_date_start));
+            tmp3 = g_strdup(orage_tm_date_to_i18_date(&tm_date_end));
+            tmp = g_strdup_printf(_("<b>Events for %s - %s:</b>"), tmp2, tmp3);
+            g_free(tmp2);
+            g_free(tmp3);
+        }
+        gtk_label_set_markup(GTK_LABEL(cal->mEvent_label), tmp);
+        g_free(tmp);
     }
-    gtk_label_set_markup(GTK_LABEL(cal->mEvent_label), tmp);
-    g_free(tmp);
 
     gtk_box_pack_start(GTK_BOX(cal->mEvent_vbox), cal->mEvent_label
             , FALSE, FALSE, 0);
